@@ -41,7 +41,8 @@ class OutboxEncryption:
 
     # PS1 for environmnet linux
     # VENV for environment windows
-    env_list = ['PS1', 'VENV']                # os.environ.get("PS1") --> list of environment
+    # env_list = ['PS1', 'VENV', 'PYENV_VERSION'] # os.environ.get("PS1") --> list of environment
+    env_list = ['VENV2'] # os.environ.get("PS1") --> list of environment
     # env_local = '.env.local'        # environment name local    (DELETE pending)
     # env_server = '.env.server'      # environment name server   (DELETE pending)
     env_name = '.env'               # + keyword_local (after string replace all symbol to _)
@@ -145,7 +146,7 @@ class OutboxEncryption:
                 tmp = self.env_name + '.' + self.string_replace(self.keyword_local[i])
                 file_path.append(os.path.join(self.BASE_DIR, tmp))
                 # print('file_path =', file_path, Path(file_path).is_file())
-                
+                print('file_path[i]=', file_path[i])
                 # create file if not exists
                 self.create_env_file(file_path[i])
                 
@@ -243,22 +244,28 @@ class OutboxEncryption:
             for i in range(len(self.keyword_local)):                
                 find_env_name.append(self.string_replace(self.keyword_local[i]))
                 tmp = self.env_name + '.' + find_env_name[i]
-                # print('find_env_name = ' , tmp)
+                
+                print('find_env_name = ' , tmp)
+                print('path lengkap=', os.path.join(self.BASE_DIR, tmp))
+
                 file_path.append(os.path.join(self.BASE_DIR, tmp))
                 # print('file_path =', file_path, Path(file_path).is_file())
                 
+                print('create file if not exists', file_path[i])
                 # create file if not exists
                 self.create_env_file(file_path[i])
 
             # print('file_path = ',file_path)
 
             # Baca data dari variable ENV, jika ketemu data dari list (keyword_local) maka load data dari file itu
+            print('self.env_list=',self.env_list)
             for j in range(len(self.env_list)):   
                 env_list_split = []
                 env_list_split2 = [] # karena ada tag pembuka dan penutup, maka split 2 kali
 
                 # print('proses ', self.env_list[j])
                 env_list = os.getenv(self.env_list[j]) # PS1 atau VENV
+                print('env_list=',env_list)
                 # env_list = os.environ.get(self.env_list[j]) # PS1 atau VENV
                 # print('env_list=',env_list)
                 is_found = False
@@ -314,7 +321,8 @@ class OutboxEncryption:
                 if env_list:
                     file_path_idx = -1
                     for i in self.keyword_local:
-                        # print('i=',i)
+                        print('keyword_local=',i)
+                        print('data=', env_list_split2)
                         file_path_idx += 1
                         if i in env_list_split2:
                             # env_config = Config(RepositoryEnv(self.BASE_DIR / self.env_local))
